@@ -24,7 +24,7 @@ Usage::
 from datetime import datetime
 from decimal import Decimal
 import sys
-from typing import Any, Dict, Generator, List, Set, TYPE_CHECKING, Union
+from typing import Any, Dict, Iterator, List, Set, TYPE_CHECKING, Union
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_dynamodb.type_defs import (
     ConditionTypeDef,
@@ -53,7 +53,7 @@ __all__ = (
 
 class ListBackupsPaginator(Boto3Paginator):
     """
-    [Paginator.ListBackups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
+    [Paginator.ListBackups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
     """
 
     def paginate(
@@ -63,41 +63,41 @@ class ListBackupsPaginator(Boto3Paginator):
         TimeRangeUpperBound: datetime = None,
         BackupType: Literal["USER", "SYSTEM", "AWS_BACKUP", "ALL"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListBackupsOutputTypeDef, None, None]:
+    ) -> Iterator[ListBackupsOutputTypeDef]:
         """
-        [ListBackups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
+        [ListBackups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
         """
 
 
 class ListTablesPaginator(Boto3Paginator):
     """
-    [Paginator.ListTables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
+    [Paginator.ListTables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListTablesOutputTypeDef, None, None]:
+    ) -> Iterator[ListTablesOutputTypeDef]:
         """
-        [ListTables.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
+        [ListTables.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
         """
 
 
 class ListTagsOfResourcePaginator(Boto3Paginator):
     """
-    [Paginator.ListTagsOfResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
+    [Paginator.ListTagsOfResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
     """
 
     def paginate(
         self, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListTagsOfResourceOutputTypeDef, None, None]:
+    ) -> Iterator[ListTagsOfResourceOutputTypeDef]:
         """
-        [ListTagsOfResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
+        [ListTagsOfResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
         """
 
 
 class QueryPaginator(Boto3Paginator):
     """
-    [Paginator.Query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
+    [Paginator.Query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
     """
 
     def paginate(
@@ -138,15 +138,15 @@ class QueryPaginator(Boto3Paginator):
             ],
         ] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[QueryOutputTypeDef, None, None]:
+    ) -> Iterator[QueryOutputTypeDef]:
         """
-        [Query.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
+        [Query.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
         """
 
 
 class ScanPaginator(Boto3Paginator):
     """
-    [Paginator.Scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
+    [Paginator.Scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
     """
 
     def paginate(
@@ -186,7 +186,7 @@ class ScanPaginator(Boto3Paginator):
         ] = None,
         ConsistentRead: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ScanOutputTypeDef, None, None]:
+    ) -> Iterator[ScanOutputTypeDef]:
         """
-        [Scan.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
+        [Scan.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
         """
