@@ -17,7 +17,7 @@ Usage::
 from datetime import datetime
 from decimal import Decimal
 import sys
-from typing import Any, Dict, List, Set, TYPE_CHECKING, Type, TypeVar, Union
+from typing import Any, Dict, Iterator, List, Set, TYPE_CHECKING, TypeVar, Union
 from boto3.dynamodb.table import BatchWriter
 from boto3.resources.base import ServiceResource as Boto3ServiceResource
 from boto3.resources.collection import ResourceCollection
@@ -27,7 +27,6 @@ from mypy_boto3_dynamodb.type_defs import (
     BatchGetItemOutputTypeDef,
     BatchWriteItemOutputTypeDef,
     ConditionTypeDef,
-    CreateTableOutputTypeDef,
     DeleteItemOutputTypeDef,
     DeleteTableOutputTypeDef,
     ExpectedAttributeValueTypeDef,
@@ -46,7 +45,6 @@ from mypy_boto3_dynamodb.type_defs import (
     StreamSpecificationTypeDef,
     TagTypeDef,
     UpdateItemOutputTypeDef,
-    UpdateTableOutputTypeDef,
     WriteRequestTypeDef,
 )
 
@@ -58,53 +56,36 @@ else:
 
 __all__ = ("DynamoDBServiceResource", "Table", "ServiceResourceTablesCollection")
 
-_ServiceResourceTablesCollectionType = TypeVar(
-    "_ServiceResourceTablesCollectionType", bound="ServiceResourceTablesCollection"
-)
-
 
 class ServiceResourceTablesCollection(ResourceCollection):
     """
-    [ServiceResource.tables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
+    [ServiceResource.tables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
     """
 
-    @classmethod
-    def all(
-        cls: Type[_ServiceResourceTablesCollectionType],
-    ) -> Type[_ServiceResourceTablesCollectionType]:
+    def all(self) -> "ServiceResourceTablesCollection":
         pass
 
-    @classmethod
     def filter(
-        cls: Type[_ServiceResourceTablesCollectionType],
-        ExclusiveStartTableName: str = None,
-        Limit: int = None,
-    ) -> Type[_ServiceResourceTablesCollectionType]:
+        self, ExclusiveStartTableName: str = None, Limit: int = None
+    ) -> "ServiceResourceTablesCollection":
         pass
 
-    @classmethod
-    def limit(
-        cls: Type[_ServiceResourceTablesCollectionType], count: int
-    ) -> Type[_ServiceResourceTablesCollectionType]:
+    def limit(self, count: int) -> "ServiceResourceTablesCollection":
         pass
 
-    @classmethod
-    def page_size(
-        cls: Type[_ServiceResourceTablesCollectionType], count: int
-    ) -> Type[_ServiceResourceTablesCollectionType]:
+    def page_size(self, count: int) -> "ServiceResourceTablesCollection":
         pass
 
-    @classmethod
-    def pages(cls: Type[_ServiceResourceTablesCollectionType]) -> List["Table"]:
+    def pages(self) -> Iterator["Table"]:
         pass
 
-
-_TableType = TypeVar("_TableType", bound="Table")
+    def __iter__(self) -> Iterator["Table"]:
+        pass
 
 
 class Table(Boto3ServiceResource):
     """
-    [Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+    [Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
     """
 
     attribute_definitions: List[Any]
@@ -132,12 +113,12 @@ class Table(Boto3ServiceResource):
 
     def batch_writer(self, overwrite_by_pkeys: List[str] = None) -> BatchWriter:
         """
-        [Table.batch_writer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
+        [Table.batch_writer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
         """
 
     def delete(self) -> DeleteTableOutputTypeDef:
         """
-        [Table.delete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.delete)
+        [Table.delete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.delete)
         """
 
     def delete_item(
@@ -189,12 +170,12 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> DeleteItemOutputTypeDef:
         """
-        [Table.delete_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
+        [Table.delete_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Table.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
+        [Table.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
         """
 
     def get_item(
@@ -225,12 +206,12 @@ class Table(Boto3ServiceResource):
         ExpressionAttributeNames: Dict[str, str] = None,
     ) -> GetItemOutputTypeDef:
         """
-        [Table.get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.get_item)
+        [Table.get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.get_item)
         """
 
     def load(self) -> None:
         """
-        [Table.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.load)
+        [Table.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.load)
         """
 
     def put_item(
@@ -282,7 +263,7 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> PutItemOutputTypeDef:
         """
-        [Table.put_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.put_item)
+        [Table.put_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.put_item)
         """
 
     def query(
@@ -343,12 +324,12 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> QueryOutputTypeDef:
         """
-        [Table.query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.query)
+        [Table.query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.query)
         """
 
     def reload(self) -> None:
         """
-        [Table.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.reload)
+        [Table.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.reload)
         """
 
     def scan(
@@ -408,7 +389,7 @@ class Table(Boto3ServiceResource):
         ConsistentRead: bool = None,
     ) -> ScanOutputTypeDef:
         """
-        [Table.scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.scan)
+        [Table.scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.scan)
         """
 
     def update(
@@ -420,9 +401,9 @@ class Table(Boto3ServiceResource):
         StreamSpecification: StreamSpecificationTypeDef = None,
         SSESpecification: SSESpecificationTypeDef = None,
         ReplicaUpdates: List[ReplicationGroupUpdateTypeDef] = None,
-    ) -> UpdateTableOutputTypeDef:
+    ) -> "Table":
         """
-        [Table.update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.update)
+        [Table.update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.update)
         """
 
     def update_item(
@@ -476,17 +457,17 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> UpdateItemOutputTypeDef:
         """
-        [Table.update_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.update_item)
+        [Table.update_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.update_item)
         """
 
     def wait_until_exists(self) -> None:
         """
-        [Table.wait_until_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
+        [Table.wait_until_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
         """
 
     def wait_until_not_exists(self) -> None:
         """
-        [Table.wait_until_not_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
+        [Table.wait_until_not_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
         """
 
 
@@ -495,14 +476,14 @@ _Table = Table
 
 class DynamoDBServiceResource(Boto3ServiceResource):
     """
-    [DynamoDB.ServiceResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.ServiceResource)
+    [DynamoDB.ServiceResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.ServiceResource)
     """
 
     tables: ServiceResourceTablesCollection
 
     def Table(self, name: str) -> _Table:
         """
-        [ServiceResource.Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+        [ServiceResource.Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
         """
 
     def batch_get_item(
@@ -511,7 +492,7 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         ReturnConsumedCapacity: Literal["INDEXES", "TOTAL", "NONE"] = None,
     ) -> BatchGetItemOutputTypeDef:
         """
-        [ServiceResource.batch_get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
+        [ServiceResource.batch_get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
         """
 
     def batch_write_item(
@@ -521,7 +502,7 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         ReturnItemCollectionMetrics: Literal["SIZE", "NONE"] = None,
     ) -> BatchWriteItemOutputTypeDef:
         """
-        [ServiceResource.batch_write_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
+        [ServiceResource.batch_write_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
         """
 
     def create_table(
@@ -536,12 +517,12 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         StreamSpecification: StreamSpecificationTypeDef = None,
         SSESpecification: SSESpecificationTypeDef = None,
         Tags: List[TagTypeDef] = None,
-    ) -> CreateTableOutputTypeDef:
+    ) -> _Table:
         """
-        [ServiceResource.create_table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
+        [ServiceResource.create_table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [ServiceResource.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
+        [ServiceResource.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
         """
